@@ -258,7 +258,8 @@ class ProductSupplier(sequence_ordered(), ModelSQL, ModelView, MatchMixin):
             company = Company(Transaction().context['company'])
             return company.currency.id
 
-    @fields.depends('product', 'template')
+    @fields.depends(
+        'product', '_parent_product.template')
     def on_change_product(self):
         if self.product:
             self.template = self.product.template
